<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-dump?lang_cible=pt
// ** ne pas modifier le fichier **

return [

	// D
	'dump_description' => 'Cópia de segurança e restauro da base de dados em SQLite ',
	'dump_slogan' => 'Cópia de segurança e restauro da base de dados SPIP',
];
